@@ -283,6 +283,10 @@ void MainWindow::initBackend(bool resetStations)
     {
         backendParser = new parserHafasXml();
         setWindowTitle("Fahrplan (hafasXml - alpha)");
+    } else if (backendType == "parserTranslink")
+    {
+        backendParser = new parserTranslink();
+        setWindowTitle("Fahrplan Translink");
     } else
     {
        //fallback is bahn.de
@@ -400,7 +404,7 @@ void MainWindow::donateButtonClicked()
 void MainWindow::aboutButtonClicked()
 {
     QString version = APP_VER;
-    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>and CaCO3 (george@ruinelli.ch)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>DB</b>, <b>MVV</b>, <b>SBB</b>, <b>BB</b>, <b>Rejseplanen.dk</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>, <i>dehapama</i>, <i>halftux</i>");
+    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>and CaCO3 (george@ruinelli.ch)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>DB</b>, <b>MVV</b>, <b>SBB</b>, <b>BB</b>, <b>Rejseplanen.dk</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>, <i>dehapama</i>, <i>halftux</i>, <i>jonwil</i>");
     QMessageBox::about(this,
                        tr("About Fahrplan"),
                        tr(aboutMsg.toAscii()));
