@@ -24,6 +24,10 @@
 #include <QObject>
 #include <QtNetwork>
 
+//#include <QNetworkAccessManager>
+
+//#include "mainwindow.h"
+
 struct DetailResultItem
 {
     QString fromStation;
@@ -78,6 +82,10 @@ public:
     virtual ResultInfo getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode, int trainrestrictions);
     virtual ResultInfo getJourneyData(QString queryUrl);
     virtual DetailResultInfo getJourneyDetailsData(QString queryUrl);
+    virtual void httpRequestTimeout();
+
+//    void NetworkManagerInit(void);
+
     virtual bool supportsGps();
 signals:
 
@@ -87,9 +95,21 @@ protected:
     int currentRequestId;
     QEventLoop  loop;
 
+public:
+    int progress;
+    int progressTotal;
+
+
 private slots:
     void httpRequestFinished(int requestId, bool error);
+    void httpDataReadProgress(int done, int total);
+
+//    void replyFinished(QNetworkReply*);
 
 };
 
+
+
+
+
 #endif // PARSER_ABSTRACT_H
