@@ -119,9 +119,9 @@ void QValueButton::paintEvent(QPaintEvent *)
     QFontMetrics descriptionFm = QFontMetrics(descriptionFont());
 
     int textWidth = textFm.size(Qt::TextSingleLine, text()).width();
-    int descriptionWidth = descriptionFm.size(Qt::TextSingleLine, description()).width();
+    int descriptionWidth = descriptionFm.size(Qt::TextSingleLine, description().section('@',0,0)).width();
     int textHeight = textFm.size(Qt::TextSingleLine, text()).height();
-    int descriptionHeight =descriptionFm.size(Qt::TextSingleLine, description()).height();
+    int descriptionHeight =descriptionFm.size(Qt::TextSingleLine, description().section('@',0,0)).height();
 
     QRect ir = option.rect;
 
@@ -146,6 +146,6 @@ void QValueButton::paintEvent(QPaintEvent *)
     textflags |= Qt::TextWordWrap | Qt::ElideRight;
     p.setFont(descriptionFont());
     p.drawItemText(descriptionRect().translated(hOffset + (titleHOffset + (deltaText < 0 ? 0 : deltaText)), vOffset + titleVOffset), textflags,
-                    pal, isEnabled(), description(), QPalette::ButtonText);
+                    pal, isEnabled(), description().section('@',0,0), QPalette::ButtonText);
     p.restore();
 }
